@@ -52,6 +52,11 @@
 #include "http_log.h"
 #include "http_config.h"
 
+#include "apr_shm.h"
+#if !defined (WIN32) && !defined (OS2) && !defined (BEOS) && !defined (NETWARE)
+#define HAVE_UNIXD
+#include "unixd.h"
+#endif
 
 #ifdef APACHE13
 /* Functions needed for making Apache 1.3 module as similar
@@ -59,7 +64,7 @@ as possible to Apache 2 module, reducing ifdefs in the code itself*/
 #ifdef HAVE_HTTP_PROTOCOL_H
 #include "http_protocol.h"
 #endif
-#define STATUS_AND_SERVER NULL
+#define STATCODE_AND_SERVER (code) NULL
 #ifndef TRUE
 #define TRUE 1
 #define FALSE 0
@@ -132,7 +137,7 @@ extern time_t ap_restart_time;
 /* End Apache 1.3 only */
 #else
 /* Apache 2 only */
-#define STATUS_AND_SERVER 0, NULL
+#define STATCODE_AND_SERVER(__code__) __code__, NULL
 #include <http_protocol.h>
 #include <http_request.h>
 #include <util_script.h>
@@ -149,6 +154,8 @@ extern time_t ap_restart_time;
 /* End Apache 2 only */
 #endif
 
+#define STATUS_AND_SERVER STATCODE_AND_SERVER (0)
+
 /* Some defaults */
 #ifndef MONO_PREFIX
 #define MONO_PREFIX "/usr"
@@ -167,6 +174,15 @@ extern time_t ap_restart_time;
 #define APPCONFIG_DIR		NULL
 #define SOCKET_FILE		"/tmp/mod_mono_server"
 #define LISTEN_ADDRESS		"127.0.0.1"
+#define DASHBOARD_FILE "/tmp/mod_mono_dashboard"
+
+#ifndef DEFAULT_RESTART_REQUESTS
+#define DEFAULT_RESTART_REQUESTS 10000
+#endif
+
+#ifndef DEFAULT_RESTART_TIME
+#define DEFAULT_RESTART_TIME 43200
+#endif
 
 /* Converts every int sent into little endian */
 #ifdef MODMONO_BIGENDIAN
